@@ -1,5 +1,5 @@
 WITH RECURSIVE traverse(id) AS (
-  SELECT ?
+  SELECT :source
   UNION
   SELECT source FROM edges JOIN traverse ON target = id
 ) SELECT id FROM traverse;
